/*
 * Copyright (c) 2001-2005 OFFIS. This program is made available under the terms of
 * the MIT License.
 */
package org.easymock.internal;

import java.lang.reflect.Array;
import java.util.Arrays;

import org.easymock.AbstractMatcher;

public class ArrayMatcher extends AbstractMatcher {
    public String argumentToString(Object argument) {
        if (argument != null && argument.getClass().isArray()) {
            return arrayToString(createObjectArray(argument));
        } else {
            return super.argumentToString(argument);
        }
    }

    private String arrayToString(Object[] array) {
        StringBuffer result = new StringBuffer();
        for (int i = 0; i < array.length; i++) {
            result.append(super.argumentToString(array[i]));
            if (i != array.length - 1)
                result.append(", ");
        }
        return "[" + result.toString() + "]";
    }

    public boolean argumentMatches(Object expected, Object actual) {
        if (expected instanceof boolean[]) {
            return Arrays.equals((boolean[]) expected, (boolean[]) actual);
        } else if (expected instanceof byte[]) {
            return Arrays.equals((byte[]) expected, (byte[]) actual);
        } else if (expected instanceof char[]) {
            return Arrays.equals((char[]) expected, (char[]) actual);
        } else if (expected instanceof double[]) {
            return Arrays.equals((double[]) expected, (double[]) actual);
        } else if (expected instanceof float[]) {
            return Arrays.equals((float[]) expected, (float[]) actual);
        } else if (expected instanceof int[]) {
            return Arrays.equals((int[]) expected, (int[]) actual);
        } else if (expected instanceof long[]) {
            return Arrays.equals((long[]) expected, (long[]) actual);
        } else if (expected instanceof short[]) {
            return Arrays.equals((short[]) expected, (short[]) actual);
        } else if (expected instanceof Object[]) {
            return Arrays.equals((Object[]) expected, (Object[]) actual);
        } else {
            return super.argumentMatches(expected, actual);
        }
    }

    public static Object[] createObjectArray(Object array) {
        if (array instanceof Object[]) {
            return (Object[]) array;
        }
        Object[] result = new Object[Array.getLength(array)];
        for (int i = 0; i < Array.getLength(array); i++) {
            result[i] = Array.get(array, i);
        }
        return result;
    }
}